AndroidCustomMediaButton class

A custom button to be added to the Android notification display via setAndroidMediaButtons.

Constructors

AndroidCustomMediaButton(String title, String eventId, String drawableResource)
const

Properties

drawableResource → String
The name of the Android icon; must be in the Android project's "drawable" resource folder.
final
eventId → String
A unique identifier for the button, which will be returned the MediaEvent.customEventId.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited