AudioMetadata class

Metadata, used for display in the OS background audio system.

Constructors

AudioMetadata({String? id, String? title, String? album, String? artist, String? genre, double? durationSeconds, Uint8List? artBytes})
const

Properties

album → String?
final
artBytes → Uint8List?
final
artist → String?
final
durationSeconds → double?
final
genre → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited